.. preqc-lr documentation master file, created by
   sphinx-quickstart on Tue Nov  7 14:20:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

preqc-lr
====================================
preqc-lr is a software tool that performs quality control checks on long read sequencing data. 

Install
====================================
To install the latest version: ::

   git clone https://github.com/simpsonlab/preqc-lr.git

.. toctree::
   :hidden:

   introduction
   installation
   quickstart

